Index: sdk/lib/async/stream_controller.dart |
diff --git a/sdk/lib/async/stream_controller.dart b/sdk/lib/async/stream_controller.dart |
index 02f197c958677f6ae2ecc854b2dba656183dc9aa..24a9999b654b0c1a29700d3ea9e1b4155dd9e140 100644 |
--- a/sdk/lib/async/stream_controller.dart |
+++ b/sdk/lib/async/stream_controller.dart |
@@ -58,7 +58,7 @@ class StreamController<T> extends EventSink<T> { |
* |
* The [onSubscriptionStateChange] function is called when the stream |
* receives its first listener or loses its last. The current subscription |
* state can be read from [hasSubscribers]. Ignored if [:null:]. |
*/ |
StreamController.broadcast({void onPauseStateChange(), |
void onSubscriptionStateChange()}) |
@@ -77,7 +77,7 @@ class StreamController<T> extends EventSink<T> { |
* |
* The [onSubscriptionStateChange] function is called when the stream |
* receives its first listener or loses its last. The current subscription |
* state can be read from [hasSubscribers]. Ignored if [:null:]. |
*/ |
StreamController({void onPauseStateChange(), |
void onSubscriptionStateChange()}) |
@@ -101,7 +101,7 @@ class StreamController<T> extends EventSink<T> { |
bool get isPaused => stream._isInputPaused; |
/** Whether there are currently any subscribers on this [Stream]. */ |
- bool get hasSubscribers => stream._hasSubscribers; |
+ bool get hasListener => stream._hasListener; |
/** |
* Send or queue a data event. |
@@ -58,7 +58,7 @@ class StreamController<T> extends EventSink<T> { |
* The [onSubscriptionStateChange] function is called when the stream |
* receives its first listener or loses its last. The current subscription |
- * state can be read from [hasSubscribers]. Ignored if [:null:]. |
+ * state can be read from [hasListener]. Ignored if [:null:]. |
*/ |
StreamController.broadcast({void onPauseStateChange(), |
@@ -77,7 +77,7 @@ class StreamController<T> extends EventSink<T> { |
* The [onSubscriptionStateChange] function is called when the stream |
* receives its first listener or loses its last. The current subscription |
- * state can be read from [hasSubscribers]. Ignored if [:null:]. |
+ * state can be read from [hasListener]. Ignored if [:null:]. |
*/ |
StreamController({void onPauseStateChange(), |